## ROADMAP

To do list:

- [x] Run as `abyz -c code.abyz`
- [ ] PyPI registry
- [ ] Create docs
- [ ] More complex examples
- [ ] Check that no valid symbols are in .abyz files (use e.g. ascii_letters)
